# Compatible with Python 2.7 and Python 3.x
from __future__ import print_function, division, absolute_import

"""PT Dev Utility package for time operations, notifications, and decorators.

This package provides cross-compatible utilities that work on both
Python 2.7 and Python 3.x for internal development use.
"""

# Import main functions with updated names
from .notifications import send_telegram_message
from .pt_decorators import measure_execution_time
from .pt_time import (
    get_current_date_components,
    get_current_timestamp,
    get_month_year_string,
    get_iso_timestamp_ist
)
from .pt_csv import read_csv_as_dict_list
from .fake_sql import load_csv_as_records

# Legacy imports for backward compatibility
from .notifications import telegram  # Deprecated
from .pt_decorators import calculate_time  # Deprecated
from .pt_time import (
    get_current_month_year,  # Deprecated
    get_timestamp,  # Deprecated
    get_month_year,  # Deprecated
    get_iso_timestamp  # Deprecated
)
from .pt_csv import read_data_from_csv  # Deprecated
from .fake_sql import select_data  # Deprecated

__version__ = '1.0.0'
__author__ = 'PT Dev Team'

# Public API - recommended functions
__all__ = [
    'send_telegram_message',
    'measure_execution_time',
    'get_current_date_components',
    'get_current_timestamp',
    'get_month_year_string',
    'get_iso_timestamp_ist',
    'read_csv_as_dict_list',
    'load_csv_as_records',
    # Legacy functions (deprecated but maintained for compatibility)
    'telegram',
    'calculate_time',
    'get_current_month_year',
    'get_timestamp',
    'get_month_year',
    'get_iso_timestamp',
    'read_data_from_csv',
    'select_data'
]